/*
 * This file is a component of thundr, a software library from 3wks.
 * Read more: http://www.3wks.com.au/thundr
 * Copyright (C) 2013 3wks, <thundr@3wks.com.au>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.threewks.thundr.view.handlebars;

import java.util.Collections;
import java.util.Map;

import org.apache.commons.lang3.StringUtils;

import com.threewks.thundr.view.View;

public class HandlebarsView implements View {
	private String view;
	private Map<String, Object> model;

	public HandlebarsView(String view) {
		this(view, Collections.<String, Object> emptyMap());
	}

	public HandlebarsView(String view, Map<String, Object> model) {
		super();
		this.view = view;
		this.model = model;
	}

	public Map<String, Object> getModel() {
		return model;
	}

	public String getView() {
		return completeViewName(view);
	}

	private String completeViewName(String view) {
		if (!StringUtils.startsWith(view, "/")) {
			view = "/WEB-INF/hbs/" + view;
		}
		if (!StringUtils.contains(view, ".")) {
			view = view + ".hbs";
		}
		return view;
	}

	@Override
	public String toString() {
		String completeView = completeViewName(view);
		return completeView.equals(view) ? view : String.format("%s (%s)", view, completeView);
	}
}
