/*
 * This file is a component of thundr, a software library from 3wks.
 * Read more: http://www.3wks.com.au/thundr
 * Copyright (C) 2013 3wks, <thundr@3wks.com.au>
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.threewks.thundr.view.handlebars;

import java.util.Collections;
import java.util.Map;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;

import com.threewks.thundr.view.ViewResolver;

/**
 * Resolves a specific handlebars view every time passing the view result in the model as the attribute 'data'.
 * 
 * For example,
 * 
 * <pre>
 * <code>
 * SpecificHandlebarsViewResolver&lt;NotFoundException&gt; viewResolver = new SpecificHandlebarsViewResolver&lt;NotFoundException&gt;("404.hbs", false);
 * </code>
 * </pre>
 */
public class SpecificHandlebarsViewResolver<View> implements ViewResolver<View> {
	private ViewResolver<HandlebarsView> resolver;
	private String view;

	public SpecificHandlebarsViewResolver(String view, boolean debug) {
		resolver = new HandlebarsViewResolver(debug);
		this.view = view;
	}

	@Override
	public void resolve(HttpServletRequest req, HttpServletResponse resp, View viewResult) {
		Map<String, Object> model = Collections.<String, Object> singletonMap("data", viewResult);
		HandlebarsView view = new HandlebarsView(this.view, model);
		resolver.resolve(req, resp, view);
	}

	public String getView() {
		return view;
	}

	@Override
	public String toString() {
		return String.format("%s(%s)", this.getClass().getSimpleName(), view);
	}
}
